Equations Solved
================

A detailed description of the equations solved by
the various pyqg models

.. toctree::
    :maxdepth: 2

    equations/notation_twolayer_model
    equations/notation_layered
    equations/notation_verticalmodes
    equations/notation_linearstability
    equations/notation_equivalent_barotropic
    equations/notation_sqg_model
